@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 #########################################################
-## Thai Language Toolkit : version  1.6.1
+## Thai Language Toolkit : version  1.6.7
 ## Chulalongkorn University
 ## written by Wirote Aroonmanakun
 ## Implemented :
@@ -11,6 +11,7 @@
 ##      TNC_load(), TNC3g_load(), trigram_load(Filename), unigram(w1), bigram(w1,w2), trigram(w1,w2,w3)
 ##      collocates(w,SPAN,STAT,DIR,LIMIT, MINFQ) = [wa,wb,wc]
 ##      w2v_exist(w), similar_words(w), similarlity(w1,w2), outofgroup(WORDLST), analogy(w1,w2,w3) 
+##      compound(w1,w2)
 #########################################################
 
 import re
@@ -523,7 +524,26 @@ def w2v(w):
         return(w2v_model.wv[w])
     else:
         return()
-    
+
+## compare w1,w2, w12 returned sorted list of similarity
+def compound(w1,w2):
+    global w2v_model
+    try:
+      w2v_model
+    except NameError:
+      w2v_load()
+    vocabs = list(w2v_model.wv.index_to_key)
+    w12 = w1+w2
+    if w12 not in vocabs or w1 not in vocabs or w2 not in vocabs:
+        return([])  ## not a compound or w1,w2 not exist
+    else:    
+        if w1 in vocabs and w2 in vocabs:
+            d1 = w2v_model.wv.similarity(w1,w12)
+            d2 = w2v_model.wv.similarity(w2,w12)
+            d3 = w2v_model.wv.similarity(w1,w2)
+            lst = [((w1,w12),d1),((w2,w12),d2),((w1,w2),d3)]
+            return(sorted(lst, key=lambda x: x[1], reverse=True))
+
 def similarity(w1,w2):
     global w2v_model
     degree = ''
@@ -696,7 +716,18 @@ def w2v_compare_color(wds):
 
 
 ## testing area
+
+
 '''
+
+x = compound('วาง','เงิน')
+print(x)
+x = compound('กลัด','กลุ้ม')
+print(x)
+x = compound('เล็ก','น้อย')
+print(x)
+
+
 pars = Corpus_build('/Users/macbook/Cloud/Dropbox/Corpus/corpora/ThaiNews',sep="edu",filetype="txt")
 print(pars[0:3])
 
